tropical_gemm_inner

Function tropical_gemm_inner 

pub unsafe fn tropical_gemm_inner<T: TropicalSemiring, K: Microkernel<T> + Sync>(
    m: usize,
    n: usize,
    k: usize,
    a: *const T::Scalar,
    lda: usize,
    trans_a: Transpose,
    b: *const T::Scalar,
    ldb: usize,
    trans_b: Transpose,
    c: *mut T,
    ldc: usize,
    params: &TilingParams,
    kernel: &K,
)
Tropical GEMM with custom kernel and tiling parameters.

With the parallel feature, large outputs are partitioned across Rayon workers. The shared microkernel must implement Sync. Each output cell retains its complete, serial K reduction.

Safety

Same requirements as tropical_gemm_portable