AdditiveTropical

Trait AdditiveTropical 

pub trait AdditiveTropical: TropicalWithArgmax<Index = u32> { }
Semirings whose multiplication is ordinary addition, with unit local derivatives. Used to restrict gradient routing that does not require the input operands.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors